# -*- coding: utf-8 -*-
"""The package 'filesysobjects' provides utilities for the handling of
filesystems as class trees containing objects as files.

"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

__package__ = 'filesysobjects'
__all__=[
    "FileSysObjects",
]

